diff src/share/vm/memory/allocation.hpp @ 11020:3a0774193f71

Merge
author chegar
date Wed, 19 Jun 2013 11:02:10 +0100
parents eaf3742822ec f2110083203d
children 9f3e3245b50f
line wrap: on
line diff
--- a/src/share/vm/memory/allocation.hpp	Mon Jun 17 11:17:49 2013 +0100
+++ b/src/share/vm/memory/allocation.hpp	Wed Jun 19 11:02:10 2013 +0100
@@ -157,7 +157,8 @@
   mtJavaHeap          = 0x0C00,  // Java heap
   mtClassShared       = 0x0D00,  // class data sharing
   mtTest              = 0x0E00,  // Test type for verifying NMT
-  mt_number_of_types  = 0x000E,  // number of memory types (mtDontTrack
+  mtTracing           = 0x0F00,  // memory used for Tracing
+  mt_number_of_types  = 0x000F,  // number of memory types (mtDontTrack
                                  // is not included as validate type)
   mtDontTrack         = 0x0F00,  // memory we do not or cannot track
   mt_masks            = 0x7F00,